@@ -165,10 +165,8 @@ static void
 eel_background_class_init (gpointer klass)
 {
 	GObjectClass *object_class;
-	EelBackgroundClass *background_class;
 
 	object_class = G_OBJECT_CLASS (klass);
-	background_class = EEL_BACKGROUND_CLASS (klass);
 
 	eel_type_init ();
 
@@ -553,6 +551,7 @@ eel_background_image_totally_obscures (EelBackground *background)
 	switch (background->details->image_placement) {
 	case EEL_BACKGROUND_TILED:
 	case EEL_BACKGROUND_SCALED:
+	case EEL_BACKGROUND_ZOOM:
 		return TRUE;
 	default:
 		g_assert_not_reached ();
@@ -678,6 +677,24 @@ eel_background_ensure_image_scaled (EelBackground *background, int dest_width, i
 				}
 			}
 			break;
+		case EEL_BACKGROUND_ZOOM:
+			eel_gdk_scale_to_min_factor (background->details->image_width_unscaled,
+						     background->details->image_height_unscaled,
+						     dest_width, dest_height,
+						     &fit_width, &fit_height);
+
+			if (image_width != fit_width || image_height != fit_height) {
+				if (cur_scaled) {
+					reload_image = TRUE;
+				} else {
+					scaled_pixbuf = eel_gdk_pixbuf_scale_to_min (background->details->image, dest_width, dest_height);
+					g_object_unref (background->details->image);
+					background->details->image = scaled_pixbuf;
+					image_width = gdk_pixbuf_get_width (scaled_pixbuf);
+					image_height = gdk_pixbuf_get_height (scaled_pixbuf);
+				}
+			}
+			break;
 		}
 
 		if (reload_image) {
@@ -759,6 +776,7 @@ get_pixmap_size (EelBackground    *background,
 		case EEL_BACKGROUND_CENTERED:
 		case EEL_BACKGROUND_SCALED:
 		case EEL_BACKGROUND_SCALED_ASPECT:
+		case EEL_BACKGROUND_ZOOM:
 			*pixmap_width = entire_width;
 			*pixmap_height = entire_height;
 		}
@@ -1356,6 +1374,7 @@ eel_background_draw_aa (EelBackground *background, EelCanvasBuf *buffer)
 		case EEL_BACKGROUND_CENTERED:
 		case EEL_BACKGROUND_SCALED:
 		case EEL_BACKGROUND_SCALED_ASPECT:
+		case EEL_BACKGROUND_ZOOM:
 			/* Since the image has already been scaled, all these cases
 			 * can be treated identically.
 			 */
