@@ -222,13 +222,14 @@ file_read_callback (GnomeVFSAsyncHandle *vfs_handle,
 					      bytes_read,
 					      NULL)) {
 			result = GNOME_VFS_ERROR_WRONG_FORMAT;
+		} else {
+			gnome_vfs_async_read (handle->vfs_handle,
+					      handle->buffer,
+					      sizeof (handle->buffer),
+					      file_read_callback,
+					      handle);
+			return;
 		}
-		gnome_vfs_async_read (handle->vfs_handle,
-				      handle->buffer,
-				      sizeof (handle->buffer),
-				      file_read_callback,
-				      handle);
-		return;
 	}
 
 	load_done (handle, result, result == GNOME_VFS_OK || result == GNOME_VFS_ERROR_EOF);
@@ -295,7 +296,7 @@ eel_gdk_pixbuf_average_value (GdkPixbuf *pixbuf)
 	int row_stride;
 	const guchar *pixels, *p;
 	int r, g, b, a;
-	guint dividend;
+	guint64 dividend;
 	guint width, height;
 
 	width = gdk_pixbuf_get_width (pixbuf);
@@ -403,6 +404,37 @@ eel_gdk_pixbuf_scale_down_to_fit (GdkPixbuf *pixbuf, int max_width, int max_heig
 	}
 }
 
+double
+eel_gdk_scale_to_min_factor (int width, int height,
+			     int min_width, int min_height,
+			     int *scaled_width, int *scaled_height)
+{
+	double scale_factor;
+
+	scale_factor = MAX (min_width / (double) width, min_height / (double) height);
+
+	*scaled_width  = floor (width * scale_factor + .5);
+	*scaled_height = floor (height * scale_factor + .5);
+
+	return scale_factor;
+}
+
+/* Returns a scaled copy of pixbuf, preserving aspect ratio. The copy will
+ * be scaled as small as possible without going under the specified width and height.
+ */
+GdkPixbuf *
+eel_gdk_pixbuf_scale_to_min (GdkPixbuf *pixbuf, int min_width, int min_height)
+{
+	int scaled_width;
+	int scaled_height;
+
+	eel_gdk_scale_to_min_factor (gdk_pixbuf_get_width(pixbuf), gdk_pixbuf_get_height(pixbuf),
+				     min_width, min_height,
+				     &scaled_width, &scaled_height);
+
+	return gdk_pixbuf_scale_simple (pixbuf, scaled_width, scaled_height, GDK_INTERP_BILINEAR);	
+}
+
 /**
  * eel_gdk_pixbuf_is_valid:
  * @pixbuf: A GdkPixbuf
@@ -592,34 +624,16 @@ eel_gdk_pixbuf_draw_to_drawable (const GdkPixbuf *pixbuf,
 	target.x1 = target.x0 + MIN (target_width, source_width);
 	target.y1 = target.y0 + MIN (target_height, source_height);
 
-	if (gdk_pixbuf_get_has_alpha (pixbuf)) {
-		gdk_pixbuf_render_to_drawable_alpha ((GdkPixbuf *) pixbuf,
-						     drawable,
-						     source.x0,
-						     source.y0,
-						     target.x0,
-						     target.y0,
-						     target.x1 - target.x0,
-						     target.y1 - target.y0,
-						     alpha_compositing_mode,
-						     alpha_threshold,
-						     dither,
-						     0,
-						     0);
-	} else {
-		gdk_pixbuf_render_to_drawable ((GdkPixbuf *) pixbuf,
-					       drawable,
-					       gc,
-					       source.x0,
-					       source.y0,
-					       target.x0,
-					       target.y0,
-					       target.x1 - target.x0,
-					       target.y1 - target.y0,
-					       dither,
-					       0,
-					       0);
-	}
+	gdk_draw_pixbuf (drawable, gc, (GdkPixbuf *) pixbuf,
+			 source.x0,
+			 source.y0,
+			 target.x0,
+			 target.y0,
+			 target.x1 - target.x0,
+			 target.y1 - target.y0,
+			 dither,
+			 0,
+			 0);
 }
 
 /**
